Module alloc

Module alloc 

Ling heap allocation.

Structs

LingBox
A heap-allocated Ling value box backed by the system allocator (or mimalloc when the mimalloc feature is enabled).

Functions

raw_alloc
Allocate size bytes with align alignment using the system allocator. Returns a null pointer on allocation failure.
raw_dealloc
Deallocate a previously-allocated block.